/*
 * This is part of the doxml library.  It allows the application to specify
 *  URI handlers which can be used to fetch the bodies pointed to by
 *  external_ids.
 *
 * (For those who don't know: URIs are Uniform Resource Identifiers--
 *  a superset of URLs.)
 *
 * Copyright (C) 1999 John Stracke, http://www.thibault.org
 *
 * This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 *  02111-1307, USA.
 *
 * $Log: uri.h,v $
 * Revision 1.3  1999/07/04 22:45:50  francis
 * Clarifying a comment
 *
 * Revision 1.2  1999/06/25 21:17:37  francis
 * Changing DOXML_XML to DOXML_XML; adding idents
 *
 * Revision 1.1  1999/06/25 21:15:00  francis
 * Adding a framework for the application to provide doxml with URI
 * handlers for use in processing external IDs.  (Not providing URI
 * code as part of doxml means we can work with whatever URI code the
 * app wants, and don't have to write anything non-portable.)
 *
 * Also, changing old _LIBXML_ stuff in the headers to _DOXML_.
 *
 */

#ifndef _DOXML_DOXML_URI_H_
#define _DOXML_DOXML_URI_H_

static const char* _doxml_version_ident_doxml_uri_h="$Id: uri.h,v 1.3 1999/07/04 22:45:50 francis Exp $";

#include <doxml/xml.h>

typedef enum {
  doxml_uri_error_none,
  doxml_uri_error_unsupported_scheme,
  doxml_uri_error_bad_uri_syntax,
  doxml_uri_error_no_such_host,
  doxml_uri_error_conn_refused,
  doxml_uri_error_authentication,
  doxml_uri_error_internal, /* unspecified problem in the handler */
  doxml_uri_error_network,  /* unspecified problem in the network or server */
  doxml_uri_error_unknown
} doxml_uri_error;

/* This function must accept being called with error NULL. */
typedef const char* (*doxml_uri_handler)(doxml_context* context,
                                         void* handler_context,
                                         const char* uri,
                                         doxml_uri_error* error);

struct doxml_uri_handler_ref_tag;
typedef struct doxml_uri_handler_ref_tag doxml_uri_handler_ref;

/* Registers handler as a URI handler for context.  When handler is invoked,
 *  it will be passed handler_context as its handler_context parameter.
 *
 * Returns a doxml_uri_handler_ref, a pointer to an opaque struct
 *  which can later be passed to doxml_unregister_uri_handler(), below.
 */
doxml_uri_handler_ref* doxml_register_uri_handler(doxml_context* context,
                                                  doxml_uri_handler handler,
                                                  void* handler_context);
void doxml_unregister_uri_handler(doxml_uri_handler_ref* ref);

/* It is legitimate to call this function with error NULL.  You just
 *  won't get error codes returned.
 */
const char* doxml_load_uri(doxml_context* context,
                           const char* uri,
                           doxml_uri_error* error);

#endif /*_DOXML_DOXML_URI_H_*/
