/*
 * This is part of the doxml library, a parser for XML.  It should not
 *  require any functionality not defined in ANSI C's standard libraries.
 *
 * Copyright (C) 1999 John Stracke, http://www.thibault.org
 *
 * This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 *  02111-1307, USA.
 *
 * $Log: constrct.c,v $
 * Revision 1.9  1999/07/24 20:23:51  francis
 * Adding support for param entities in the DTD
 *
 * Revision 1.8  1999/07/24 13:43:46  francis
 * Adding support for namespaces in entity names.
 *
 * Revision 1.7  1999/07/18 20:25:06  francis
 * Moving the global buff (static in parse.c) into the doxml_context,
 * to make the parser reentrant, so that it can be used from two threads
 * simultaneously.  Documenting the change; updating the version number
 * of the manual.
 *
 * Revision 1.6  1999/06/25 21:15:00  francis
 * Adding a framework for the application to provide doxml with URI
 * handlers for use in processing external IDs.  (Not providing URI
 * code as part of doxml means we can work with whatever URI code the
 * app wants, and don't have to write anything non-portable.)
 *
 * Also, changing old _LIBXML_ stuff in the headers to _DOXML_.
 *
 * Revision 1.5  1999/06/25 19:43:02  francis
 * Adding support for unparsed entities
 *
 * Revision 1.4  1999/05/21 23:10:28  francis
 * Reformatting, since renaming to doxml changed the widths of the
 * identifiers.
 *
 * Revision 1.3  1999/05/21 23:05:42  francis
 * Finished renaming to doxml
 *
 * Revision 1.2  1999/05/21 22:59:48  francis
 * Partially renaming to doxml
 *
 * Revision 1.1.1.1  1999/05/21 22:20:36  francis
 * Initial checkin of libxml, to be renamed doxml
 *
 */

static const char* id="$Id: constrct.c,v 1.9 1999/07/24 20:23:51 francis Exp $";

#include <doxml/priv.h>
#include <stdlib.h>

doxml_context*
doxml_construct_context(doxml_getc_method getc_method,
                        doxml_destructor_method destructor_method)
{
  doxml_context* res;

  if (!getc_method)
    {
      fprintf(stderr,"doxml: doxml_construct_context(): getc_method is NULL\n");
      return 0;
    }

  res=(doxml_context*)malloc(sizeof(doxml_context));
  if (!res)
    {
      fprintf(stderr,"doxml: doxml_construct_context(): malloc() failed\n");
      return 0;
    }

  res->reader.getc_method=getc_method;
  res->reader.destructor_method=destructor_method;
  res->reader.closure=0;

  res->pushed=0;
  res->ungetc_buff=-1;

  res->external_entity=0;
  res->compound_uri_handler=0;

  res->buff.data=0;
  res->buff.size=res->buff.actual=0;

  res->line_number=1;

  return res;
}
