/*
 * This is part of the doxml library, a parser for XML.  It should not
 *  require any functionality not defined in ANSI C's standard libraries.
 *
 * Copyright (C) 1999 John Stracke, http://www.thibault.org
 *
 * This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 *  02111-1307, USA.
 *
 * $Log: lookuppr.c,v $
 * Revision 1.8  1999/07/24 16:55:28  francis
 * Adding support for entity-valued attributes
 *
 * Revision 1.7  1999/07/19 01:31:12  francis
 * Implementing namespace reform (but not using it yet).  Not documented yet.
 *
 * Revision 1.6  1999/06/07 04:57:38  francis
 * Implementing processing instructions.  Note the API changes.
 *
 * Revision 1.5  1999/05/22 14:29:20  francis
 * Removing the case-insensitive compare, since it turns out XML tags are
 * case-sensitive.
 *
 * Revision 1.4  1999/05/21 23:10:28  francis
 * Reformatting, since renaming to doxml changed the widths of the
 * identifiers.
 *
 * Revision 1.3  1999/05/21 23:05:42  francis
 * Finished renaming to doxml
 *
 * Revision 1.2  1999/05/21 22:59:48  francis
 * Partially renaming to doxml
 *
 * Revision 1.1.1.1  1999/05/21 22:20:36  francis
 * Initial checkin of libxml, to be renamed doxml
 *
 */

static const char* id="$Id: lookuppr.c,v 1.8 1999/07/24 16:55:28 francis Exp $";

#include <doxml/priv.h>

const char* doxml_lookup_prefix(doxml_atom* atom,
                                const char* namespace)
{
  if (!namespace)
    return 0;
  if (!(namespace[0]))
    return "xmlns";

  if (!atom)
    {
      fprintf(stderr,"doxml: doxml_lookup_prefix(): atom is NULL\n");
      return 0;
    }

  {
    doxml_attribute* cur=atom->data.element.attrs.first;
    if (cur)
      {
        do
          {
            if (!(cur->name.space))
              continue;
            if (cur->name.space[0]) /* not xmlns: */
              continue;
            if (!(cur->name.name)) /* can't happen */
              continue;
            if (cur->is_entity)
              continue;
            if (!(cur->value.literal))
              continue;
            
            if (!strcmp(namespace,cur->value.literal))
              return cur->name.name;
          }
        while (cur=cur->next);
      }
  }
  
  if (atom->parent)
    return doxml_lookup_prefix(atom->parent,namespace);
  
  return 0;
}
