/*
 * This is part of the doxml library, a parser for XML.  It should not
 *  require any functionality not defined in ANSI C's standard libraries.
 *
 * Copyright (C) 1999 John Stracke, http://www.thibault.org
 *
 * This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 *  02111-1307, USA.
 *
 * $Log: stream.c,v $
 * Revision 1.5  1999/07/24 20:23:51  francis
 * Adding support for param entities in the DTD
 *
 * Revision 1.4  1999/05/21 23:10:29  francis
 * Reformatting, since renaming to doxml changed the widths of the
 * identifiers.
 *
 * Revision 1.3  1999/05/21 23:05:42  francis
 * Finished renaming to doxml
 *
 * Revision 1.2  1999/05/21 22:59:49  francis
 * Partially renaming to doxml
 *
 * Revision 1.1.1.1  1999/05/21 22:20:36  francis
 * Initial checkin of libxml, to be renamed doxml
 *
 */

static const char* id="$Id: stream.c,v 1.5 1999/07/24 20:23:51 francis Exp $";

#include <doxml/priv.h>

typedef struct {
  FILE* stream;
  int close_stream_after_parsing;
} stream_closure;

static int stream_getc_method(doxml_context* context)
{
  stream_closure* closure;
  if (!(context && (context->reader.closure)))
    return -1;

  closure=(stream_closure*)(context->reader.closure);
  if (!closure->stream)
    return -1;

  return getc(closure->stream);
}

static void stream_destructor_method(doxml_context* context)
{
  stream_closure* closure;
  if (!(context && (context->reader.closure)))
    return;

  closure=(stream_closure*)(context->reader.closure);
  if (!closure)
    return;

  if (!(closure->stream))
    return;

  if (closure->close_stream_after_parsing)
    fclose(closure->stream);
  free(closure);
  context->reader.closure=0;
}

doxml_context*
doxml_open_stream(FILE* stream,
                  int close_stream_after_parsing)
{
  doxml_context* context;
  stream_closure* closure;
  if (!stream)
    {
      fprintf(stderr,"doxml: doxml_open_stream(): stream is NULL\n");
      return 0;
    }

  context=doxml_construct_context(stream_getc_method,
                                  stream_destructor_method);
  if (!context)
    {
      fprintf(stderr,"doxml: doxml_open_stream(): cannot construct context\n");
      return 0;
    }

  closure=(stream_closure*)malloc(sizeof(stream_closure));
  if (!closure)
    {
      fprintf(stderr,"doxml: doxml_open_stream(): cannot malloc() closure\n");
      free(context);
      return 0;
    }

  closure->stream=stream;
  closure->close_stream_after_parsing=close_stream_after_parsing;
  context->reader.closure=closure;

  return context;
}
